album property

The album property of the MediaMetaData interface returns or sets the name of the album or collection containing the media to be played.

Implementation

external String get album;
set album (String value)

Implementation

external set album(String value);