pause method
void
pause()
The pause() method of the MediaRecorder interface is used
to pause recording of media streams.
When a MediaRecorder object's pause()method is called, the
browser queues a task that runs the below steps:
- If MediaRecorder.state is "inactive", raise a DOM
InvalidStateerror and terminate these steps. If not, continue to the next step. - Set MediaRecorder.state to "paused".
- Stop gathering data into the current Blob, but keep it available so that recording can be resumed later on.
- Raise a
MediaRecorder.pause_eventevent.
Implementation
external void pause();